% This script compares the effect of downsampling vs. decimation on an
% audio (music+voice) file, highlighting the aliasing introduced by the
% downsampling
% The script requires the Signal processing toolbox to be installed.

clear 
clc
close all

%Step 1: load a sample file. The file is a monophonic registration with
%sampling rate Fs = 16000 Hz, and samples quantized with 16 bits.

[y Fs]=wavread('myInput.wav')

%Step 2: define the sample rate compression factor dsr

dsr=5;

%Step 3: compare the spectrum of the original file,

[FT_original,df,frequency]=fourierTransform(y,Fs,Fs,'b');
hold on
%pause

% the version obtained by downsampling,
[y_ds_dsr]=downsample(y,dsr);
[FT_ds_dsr,df_ds_2,frequency_ds_dsr]=fourierTransform(y_ds_dsr,Fs/dsr,Fs,'r');
%pause

% and the version obtained by decimation (low pass filtering +
% downsampling)
[y_dec_dsr]=decimate(y,dsr);
[FT_dec_dsr,df_dec_dsr,frequency_dec_dsr]=fourierTransform(y_dec_dsr,Fs/dsr,Fs,'g');
%pause

axis([-Fs Fs 0 max(FT_original)*1.2])
leg_ds=sprintf('DS Order=%d',dsr);
leg_dec=sprintf('Dec Order=%d',dsr);
legend('Original',leg_ds,leg_dec)
%pause

% Step 4: play the files 
soundsc(y,Fs)
pause
soundsc(y_ds_dsr,Fs/dsr)
pause
soundsc(y_dec_dsr,Fs/dsr)
pause

% Step 5: save the files in wave format for external analysis with Audacity 
dec_out=sprintf('myOutput_dec_%d.wav',dsr)
ds_out=sprintf('myOutput_ds_%d.wav',dsr)
wavwrite(y_ds_dsr,Fs/dsr,16,ds_out)
wavwrite(y_dec_dsr,Fs/dsr,16,dec_out)
