%
% FUNCTION fourierTransform
%
% Evaluates the Fourier Transform of the
% signal represented by the input vector 'x'
% The input signal is sampled with frequency 'fc'
%
% This function returns the Fourier Transform
% and the corresponding frequency resolution ('df')

%

function [FT,df,frequency]=fourierTransform(x,fc,fc_plot,C)

% --------------------------------
% Step One - Evaluation of the FT
% --------------------------------

dt=1/fc;
N=8*(2^nextpow2(length(x)));
T=N*dt;
df=1/T;
X = fft(x,N);
X = X / N;
%mESD=abs(X).^2/(df^2);
X=abs(X/df);
FT = fftshift(X);

% -----------------------------------
% Step Two - Graphical representation
% -----------------------------------

frequency = linspace(-fc/2,fc/2,length(FT));
%figure()
PF=plot(frequency,FT,C);
set(PF,'LineWidth',[2]);
AX=gca;
set(AX,'FontSize',12);
X=xlabel('Frequency [Hz]');
set(X,'FontSize',14);
Y=ylabel('Fourier Transform [V/Hz]');
set(Y,'FontSize',14);
axis([-fc fc 0 1.2*max(FT)])